A package which adds extra widgets to CustomTKinter\
See the code on [github](https://github.com/TonyLovesCoding/CTkAddons).

> [!WARNING]\
> This project is **EXTREMELY** early in development\
> Proceed with caution!

# CTkCalender
It's a calender... **duh...**\
Use `ctkaddons.CTkCalender()`

# Date Picker
`ctkaddons.CTkDateSelect()`

# Multi Pane
Creates a side panel